from .core.trapezoidal.graph import Graph
from .core.trapezoidal.hints import Shuffler

Graph = Graph
Shuffler = Shuffler
